GridGoldenSceneLayout class
- Implemented types
Constructors
- GridGoldenSceneLayout({GoldenSceneBackground? background, GridSpacing spacing = defaultGridSpacing, GoldenSceneItemDecorator? itemDecorator})
-
const
Properties
- background → GoldenSceneBackground?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- itemDecorator → GoldenSceneItemDecorator?
-
A decoration built around each screenshot in the final scene.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- spacing → GridSpacing
-
final
Methods
-
build(
WidgetTester tester, BuildContext context, SceneLayoutContent content) → Widget -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited