SingleShotConfiguration class
Constructors
- SingleShotConfiguration({Directory? directory, String? fileName, String? description, BoxConstraints? constraints, GoldenSceneItemScaffold? itemScaffold, SceneLayout? sceneLayout, Widget? widget, WidgetBuilder? builder, GoldenSceneItemPumper? pumper, GoldenSetup? setup, int? tolerancePx, Finder? boundsFinder})
Properties
- boundsFinder → Finder?
-
final
- builder → WidgetBuilder?
-
final
- constraints → BoxConstraints?
-
Optional constraints for the golden, or unbounded if
null.final - description → String?
-
The name of the overall golden scene.
final
- directory → Directory?
-
The directory where the golden scene file will be saved.
final
- fileName → String?
-
The file name for the golden scene file, which will be saved in
_directory.final - hashCode → int
-
The hash code for this object.
no setterinherited
- itemScaffold → GoldenSceneItemScaffold?
-
final
- pumper → GoldenSceneItemPumper?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sceneLayout → SceneLayout?
-
final
- setup → GoldenSetup?
-
final
- tolerancePx → int?
-
The number of mismatched pixels that are permitted for this item before triggering
a test failure.
final
- widget → Widget?
-
final
Methods
-
copyWith(
{String? description, Directory? directory, String? fileName, BoxConstraints? constraints, GoldenSceneItemScaffold? itemScaffold, SceneLayout? sceneLayout, int? tolerancePx, Widget? widget, WidgetBuilder? builder, GoldenSceneItemPumper? pumper, GoldenSetup? setup, Finder? boundsFinder}) → SingleShotConfiguration -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited